@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2024-11-22 17:10:05
-@LastEditTime: 2025-07-11 11:42:16
+@LastEditTime: 2025-07-17 20:38:41
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -48,7 +48,7 @@ class TradeStatusInfo:
 
     @classmethod
     def get_field_list(self):
-        return ['id','user_id', 'business_id', 'store_id', 'main_pay_order_no', 'order_status', 'platform_id', 'change_date', 'main_pay_order_no', 'is_sync', 'sync_date']
+        return ['id','user_id', 'business_id', 'store_id', 'main_pay_order_no', 'order_status', 'platform_id', 'change_date', 'is_sync', 'sync_date']
 
     @classmethod
     def get_primary_key(self):
